class Calc:

    def add(self, x, y):
        return x+y

    def product(self, x, y):
        return x*y

    def exponent(self, x, y):
        return x**y

    @staticmethod
    def power(x):
        return x**2



# Jakaś zmienna
test = "wartość"

# Jakaś funkcja
def func():
    print("Jestem funkcją.")

# Jakaś klasa
class Klasa:
    def pisze(self):
        print("Jestem klasą.")

print(__name__)
if __name__ == "__main__":
    # Jakiś print
    print("Napis")



from setuptools import setup, find_packages

setup(
    name="pytwwa5",
    version='0.7',
    packages=find_packages(),
    description="Our first Python distribution package",
    author="Unknown",
    author_email = "unknown@gmail.com"
)
